#

##

##

    	Earth

    	important

    		rhythms:
    			UTC from Caesarian from Gregorian

    			Chinese

    			Mayan

    	code

    		days = [
    			"monday",
    			"tuesday",
    			"wednesday",
    			"thursday",
    			"friday",
    			"saturday",
    			"sundary"
    		]

    		days_per_month_strings = {
    			"january": 31,
    			"feburary": [ 28, 29 ],
    			"march": 31,
    			"april": 30,
    			"may": 31,
    			"june": 30,
    			"july": 31,
    			"august": 31,
    			"september": 30,
    			"october": 31,
    			"november": 30,
    			"december": 31
    		}

    		month_strings = {
    			"january": 1,
    			"feburary": 2,
    			"march": 3,
    			"april": 4,
    			"may": 5,
    			"june": 6,

    			"july": 7,
    			"august": 8,
    			"september": 9,
    			"october": 10,
    			"november": 11,
    			"december": 12
    		}

    		days_per_month_integers = {
    			1: 31,
    			2: [ 28, 29 ],
    			3: 31,
    			4: 30,
    			5: 31,
    			6: 30,

    			7: 31,
    			8: 31,
    			9: 30,
    			10: 31,
    			11: 30,
    			12: 31
    		}